@@ -3,7 +3,7 @@
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory.
 
-__version__ = '1.3.3'
+__version__ = '1.3.4'
 
 __all__ = [
     'cmaes',
@@ -14,13 +14,13 @@ __all__ = [
     'gcldecpp',
     'ldecpp',
     'lgcldecpp',
-    'hhcpp',
     'bitecpp',
     'csmacpp',
     'retry',
     'advretry',
     'multiretry',
     'mode',
+    'modecpp',
     'moretry',
     'pygmoretry',
     'optimizer',
